Crate wit_bindgen_go

Crate wit_bindgen_go 

Structs

Opts

Enums

Format

Functions

remote_pkg_version
If a user specifies the pkg_name flag, the required version for the shared remote package isn’t recorded. This enables downstream users to retrieve the version programmatically.