remote_pkg_version

Function remote_pkg_version 

pub fn remote_pkg_version() -> String
If a user specifies the pkg_name flag, the required version for the shared remote package isn’t recorded. This enables downstream users to retrieve the version programmatically.